@@ -22,7 +22,7 @@
 #include <couchdb-glib.h>
 #include <utils.h>
 
-static CouchDB *couchdb;
+static CouchdbSession *couchdb;
 
 static void
 test_list_databases (void)
@@ -30,26 +30,31 @@ test_list_databases (void)
 	GError *error = NULL;
 	GSList *dblist;
 
-	dblist = couchdb_list_databases (couchdb, &error);
-	g_assert (error == NULL);
+	dblist = couchdb_session_list_databases (couchdb, &error);
+	if (error != NULL) {
+		/* A critical will abort the test case */
+		g_critical ("Error listing databases: %s", error->message);
+		g_error_free (error);
+		error = NULL;		
+	}
 
 	while (dblist != NULL) {
-		CouchDBDatabaseInfo *dbinfo;
+		CouchdbDatabaseInfo *dbinfo;
 		GSList *doclist;
 
 		error = NULL;
-		dbinfo = couchdb_get_database_info (couchdb, (const char *) dblist->data, &error);
+		dbinfo = couchdb_session_get_database_info (couchdb, (const char *) dblist->data, &error);
 		g_assert (error == NULL);
 		g_assert (dbinfo != NULL);
 		g_assert (couchdb_database_info_get_dbname (dbinfo) != NULL);
 
 		/* Get list of documents to compare against couchdb_database_info_get_documents_count */
 		error = NULL;
-		doclist = couchdb_list_documents (couchdb, (const char *) dblist->data, &error);
+		doclist = couchdb_session_list_documents (couchdb, (const char *) dblist->data, &error);
 		g_assert (error == NULL);
 		g_assert (g_slist_length (doclist) == couchdb_database_info_get_documents_count (dbinfo));
 		if (doclist)
-			couchdb_free_document_list (doclist);
+			couchdb_session_free_document_list (doclist);
 
 		dblist = g_slist_remove (dblist, dblist->data);
 		couchdb_database_info_unref (dbinfo);
@@ -62,19 +67,19 @@ test_list_documents (void)
 	GError *error = NULL;
 	GSList *dblist;
 
-	dblist = couchdb_list_databases (couchdb, &error);
+	dblist = couchdb_session_list_databases (couchdb, &error);
 	g_assert (error == NULL);
 
 	while (dblist != NULL) {
 		GSList *doclist;
 
 		error = NULL;
-		doclist = couchdb_list_documents (couchdb, (const char *) dblist->data, &error);
+		doclist = couchdb_session_list_documents (couchdb, (const char *) dblist->data, &error);
 		g_assert (error == NULL);
 
 		while (doclist) {
-			CouchDBDocumentInfo *doc_info = doclist->data;
-			CouchDBDocument *document;
+			CouchdbDocumentInfo *doc_info = doclist->data;
+			CouchdbDocument *document;
 			char *str;
 
 			error = NULL;
@@ -111,14 +116,17 @@ test_change_databases (void)
 	g_assert (dbname != NULL);
 
 	/* Create database */
-	couchdb_create_database (couchdb, dbname, &error);
-	g_assert (error == NULL);
+	couchdb_session_create_database (couchdb, dbname, &error);
+	if (error) {
+		g_critical ("Error creating database '%s': %s", dbname, error->message);
+		g_error_free (error);
+	}
 
-	couchdb_listen_for_changes (couchdb, dbname);
+	couchdb_session_listen_for_changes (couchdb, dbname);
 
 	/* Create some documents */
 	for (i = 0; i < 10; i++) {
-		CouchDBDocument *document;
+		CouchdbDocument *document;
 		char *str;
 
 		document = couchdb_document_new (couchdb);
@@ -137,7 +145,7 @@ test_change_databases (void)
 	}
 	
 	/* Delete database */
-	g_assert (couchdb_delete_database (couchdb, dbname, &error));
+	g_assert (couchdb_session_delete_database (couchdb, dbname, &error));
 	g_assert (error == NULL);
 
 	/* Free memory */
@@ -145,19 +153,19 @@ test_change_databases (void)
 }
 
 static void
-db_created_cb (CouchDB *couchdb, const char *dbname, gpointer user_data)
+db_created_cb (CouchdbSession *couchdb, const char *dbname, gpointer user_data)
 {
 	g_print ("Database %s has been created\n", dbname);
 }
 
 static void
-db_deleted_cb (CouchDB *couchdb, const char *dbname, gpointer user_data)
+db_deleted_cb (CouchdbSession *couchdb, const char *dbname, gpointer user_data)
 {
 	g_print ("Database %s has been deleted\n", dbname);
 }
 
 static void
-doc_changed_cb (CouchDB *couchdb, const char *dbname, CouchDBDocument *document, gpointer user_data)
+doc_changed_cb (CouchdbSession *couchdb, const char *dbname, CouchdbDocument *document, gpointer user_data)
 {
 	char *doc_str;
 
@@ -171,7 +179,7 @@ doc_changed_cb (CouchDB *couchdb, const char *dbname, CouchDBDocument *document,
 }
 
 static void
-doc_deleted_cb (CouchDB *couchdb, const char *dbname, const char *docid, gpointer user_data)
+doc_deleted_cb (CouchdbSession *couchdb, const char *dbname, const char *docid, gpointer user_data)
 {
 	g_print ("Document %s in database %s has been deleted\n", docid, dbname);
 }
@@ -184,9 +192,11 @@ main (int argc, char *argv[])
 	g_test_init (&argc, &argv, NULL);
 
 	/* Initialize data needed for all tests */
-	couchdb = couchdb_new (NULL);
+	couchdb =  argc > 1 ? couchdb_session_new (argv[1]) : couchdb_session_new (NULL);
+	g_printf ("Connecting to Couchdb at %s\n", couchdb_session_get_uri (couchdb));
+	
 	if (!couchdb) {
-		g_print ("Could not create CouchDB object\n");
+		g_print ("Could not create Couchdb object\n");
 		return -1;
 	}
 
